<?php

namespace App\Http\Controllers;

use App\Models\Jobs;
use Illuminate\Http\Request;
use App\Models\MeetingSchedule;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Validator;

class CandidateController extends Controller
{
    public function show($sid, $jid) {
        $response = Http::get(config('app.student_api').'/api/users/'.$sid);
        $data = $response->json();

        $view = Http::post(config('app.student_api').'/api/application/viewed/'.$sid.'/'.$jid);
        
        return view('candidates.show', [
            'candidate' => $data
        ]);
    }

    public function setMeeting($id) {
        $response = Http::get(config('app.student_api').'/api/job_applications/'.$id);
        $data = $response->json();

        // dd($data);

        $user = Http::get(config('app.student_api').'/api/users/'.$data['student_id']);
        $user = $user->json();

        $job = Jobs::findOrFail($data['job_id']);

        return view('candidates.set-meeting', [
            'student' => $user,
            'job' => $job,
            'id' => $id
        ]);
    }

    public function storeMeeting(Request $request) {

        $validator = $this->validate($request, [
            'meeting_type' => 'required|string',
            'link' => [
                function ($attribute, $value, $fail) use ($request) {
                    if (in_array($request['meeting_type'], ['meet', 'zoom']) && empty($value)) {
                        $fail('Meeting Link is required when meeting type is Google Meet or Zoom Meeting.');
                    }
                }
            ],
            'date' => 'required|string',
            'time' => 'required|string'
        ], [
            'meeting_type.required' => 'Choose a meeting type if it is On-Site or Online.',
            'link.sometimes' => 'Please provide the link of the online meeting.',
            'date.required' => 'Please choose a date.',
            'time.required' => 'Please choose a time.'
        ]);

 
        $meeting = MeetingSchedule::create([
            'application_id' => $request->app_id,
            'job_id' => $request->job_id,
            'setter_id' => $request->setter_id,
            'student_id' => $request->student_id,
            'meeting_type' => $request->meeting_type,
            'link' => $request->link,
            'date' => $request->date,
            'time' => $request->time
        ]);

        if($meeting) {
            return back()->with('success-meeting', "You have succesfully scheduled a meeting. Please wait for the student's response.");
        }

        else {
            return back()->withInput()->with('failed-meeting', "A system error has happened. Please try again.");
        }

        
    }
}
