<?php

namespace App\Http\Controllers;

use App\Models\Jobs;
use App\Models\Employee;
use Illuminate\Http\Request;
use App\Models\MeetingSchedule;
use Illuminate\Support\Facades\Http;

class DashboardController extends Controller
{
    public function index() {

        $user_id = auth()->user()->id;

        $jobs = Jobs::where('user_id', $user_id)->limit(5)->orderBy('created_at', 'desc')->get();
        // dd($jobs);

        foreach($jobs as $job) {
            $response = Http::get(config('app.student_api').'/api/job_applications', ['job_id', $job->id]);
           // Assuming the API returns an array of job applications
            $jobApplications = $response->json();

            // Filter job applications for the specific job
            $filteredApplications = array_filter($jobApplications, function ($application) use ($job) {
                return $application['job_id'] == $job->id;
            });

            // Assign the count to the job
            $job->candidateCount = count($filteredApplications);

        }

        
        return view('dashboard.index', [
            'jobs' => $jobs,
        ]);
    }

    public function jobs() {
        $user_id = auth()->user()->id;

        $jobs = Jobs::where('user_id', $user_id)->orderBy('created_at', 'desc')->paginate(5);
    
        $jobs->each(function ($job) {

            $response = Http::get(config('app.student_api').'/api/job_applications', ['job_id', $job->id]);
            // Assuming the API returns an array of job applications
             $jobApplications = $response->json();
            
             // Filter job applications for the specific job
             $filteredApplications = array_filter($jobApplications, function ($application) use ($job) {
                 return $application['job_id'] == $job->id;
             });
 
             // Assign the count to the job
             $job->candidateCount = count($filteredApplications); 

        });

        return view('dashboard.jobs', [
            'jobs' => $jobs
        ]);
    }

    public function candidates() {
        $user_id = auth()->user()->id;
        $response = Http::get(config('app.student_api').'/api/job_applications', ['user_id', $user_id]);

        // Assuming the API returns an array of job applications
        $candidates = $response->json();
        $filteredApplications = [];

        foreach($candidates as $candidate) {
            if($candidate['user_id'] == $user_id && $candidate['status'] == 1) {
                $jobId = $candidate['job_id'];
                $jobDetails = Jobs::findOrFail($jobId);
                $candidate['job_details'] = $jobDetails->getAttributes() ?? null;
                $filteredApplications[] = $candidate;
            }
        }
         return view('dashboard.candidates', [
            'candidates' => $filteredApplications
         ]);
    }

    public function employees() {
        $user_id = auth()->user()->id;
        $filteredApplications = Employee::with(['jobs'])->where('employer_id', $user_id)->get()->all();
        foreach($filteredApplications as $app) {
            $response = Http::get(config('app.student_api').'/api/users/'.$app->student_id);
            $student = $response->json();
            $app['student'] = $student;
        }
        $jobs = Jobs::all();
         return view('dashboard.employees', [
            'candidates' => $filteredApplications,
            'jobs' => $jobs
         ]);
    }

    public function recommendations() {
        $response = Http::get(config('app.school_api').'/api/recommendations');
        $recommendations = $response->json();
        // dd($recommendations);
        $filteredRecos = [];
        foreach($recommendations as $reco) {
            if($reco['company_id'] == auth()->user()->id) {
                $response = Http::get(config('app.student_api').'/api/users/'.$reco['student_id']);
                $student = $response->json();
                $jobDetails = Jobs::findOrFail($reco['job_id']);
                $studentDetails = $student;
                $reco['job_details'] = $jobDetails->getAttributes();
                $reco['student_details'] = $studentDetails;
                array_push($filteredRecos, $reco);
            }
        }
        // dd($filteredRecos);
        return view('dashboard.recommendations', [
            'recos' => $filteredRecos
        ]);
    }

    public function meetings() {
        $userID = auth()->id();
        $response = Http::get(config('app.student_api').'/api/job_applications');
        $meetings = $response->json();

        $meetings = MeetingSchedule::where('setter_id', $userID)->get();


        $finalMeetings = [];

        foreach($meetings as $meeting) {
            $jobDetails = Jobs::findOrFail($meeting['job_id']);
            $student = Http::get(config('app.student_api').'/api/users/'.$meeting['student_id']);
            $student = $student->json();
            $meeting['student'] = $student;
            $meeting['jobDetails'] = $jobDetails;
            array_push($finalMeetings, $meeting);
        }

       return view('dashboard.meetings', [
            'meetings' => $finalMeetings
       ]);
    }
}
