<?php

namespace App\Livewire;

use Livewire\Component;
use Illuminate\Http\Request;

class CreateJob extends Component
{

    public $categories;
    public $job_title;
    public $category;
    public $location;
    public $job_type;
    public $price;
    public $content;
    public $selectedAd = 2;
    public $ad_type = 'premium';
    public $success = '';
    public $step = 1;


    public function step2() {
        $validatedData = $this->validate([
            'job_title' => 'required|string',
            'category' => 'required|string',
            'location' => 'required|string',
            'job_type' => 'required|string',
            'price' => 'required_if:job_type,Paid',
            'content' => 'required'
        ], [
            'price.required_if' => 'Price is required if Job Type is Paid.'
        ]);


        $this->step = 2;
    }

    public function save() {

    }

    public function back($id) {
        $this->step = $id;
    }

    public function selectAd($id) {
        if($id == 1) {
            $this->selectedAd = 1;
            $this->ad_type = 'basic';
        } else if($id == 2) {
            $this->selectedAd = 2;
            $this->ad_type = 'premium';
        } else {
            $this->selectedAd = '';
            $this->ad_type = '';
        }
    }

    public function submit() {
        $job = Jobs::create([
            'user_id' => auth()->id(),
            'job_title' => $this->job_title,
            'category' => $this->category,
            'location' => $this->location,
            'content' => $this->content,
            'job_type' => $this->job_type,
            'ad_type' => $this->ad_type
        ]);

        $this->step = 1;
        $this->success = 'Job Ad posting success!';
        $this->clearInput();
    }

    public function clearInput() {
        $this->job_title = '';
        $this->category = '';
        $this->location = '';
        $this->content = '';
        $this->job_type = '';
        $this->ad_type = 'premium';
        $this->selectedAd = 2;
        $this->success = '';
    }

    public function render()
    {
        return view('livewire.create-job');
    }
}
